#!/usr/bin/env python3
#
# SLMP Communication sample 
# -------------------
# Copyright (C) 2020  Lineo Solutions, Inc.
#

import pymcprotocol
import random
import time


# SLMP Access for iQ-R CPU
def main():

    # Set frame type
    slmp = pymcprotocol.Type3E()
    # Set PLC type
    slmp = pymcprotocol.Type3E(plctype="iQ-R")
    # Connect PLC
    slmp.connect("192.168.7.39", 3000)

    cnt = 0
    
    while cnt < 10:
        # Make random data
        write_word_data = []
        write_word_data.append(random.randint(1,100))
        write_word_data.append(random.randint(1,100))
        write_word_data.append(random.randint(1,100))
        write_bit_data = []
        write_bit_data.append(random.randint(0,1))
        write_bit_data.append(random.randint(0,1))
        write_bit_data.append(random.randint(0,1))
        print("Count {0}".format(cnt))

        # SLMP batch word write
        slmp.batchwrite_wordunits(headdevice="D0", values=write_word_data)
        print("Batch write to D0-D2")
        # SLMP batch word read
        batch_read_val_word = slmp.batchread_wordunits(headdevice="D0", readsize=3)
        print("Batch read D0-D2 = [{0},{1},{2}]".format(batch_read_val_word[0], batch_read_val_word[1], batch_read_val_word[2]))

        # SLMP batch bit write
        slmp.batchwrite_bitunits(headdevice="M0", values=write_bit_data)
        print("Batch write to M0-M2")

        # SLMP batch bit read
        batch_read_val_bit = slmp.batchread_bitunits(headdevice="M0", readsize=3)
        print("Batch read M0-M2 = [{0},{1},{2}]".format(batch_read_val_bit[0], batch_read_val_bit[1], batch_read_val_bit[2]))

        # SLMP random word write
        slmp.randomwrite(word_devices=["D10","D12","D14"], dword_devices=["D15"], word_values=write_word_data, dword_values=[65536])
        print("Random write to D10, D12, D14, D15(DWORD)")

        # SLMP random word read
        random_read_val_word, random_read_val_dword = slmp.randomread(word_devices=["D10","D12","D14"],dword_devices=["D15"])
        print("Random read D10,D12,D14 = [{0},{1},{2}]".format(random_read_val_word[0], random_read_val_word[1], random_read_val_word[2]))
        print("Random read D15 = {0}".format(random_read_val_dword))

        # SLMP random bit write
        slmp.randomwrite_bitunits(bit_devices=["M10","M12","M14"], values=write_bit_data)
        print("Random write M10,M12,M14")

        # SLMP CPU Type Read
        cpu_type, cpu_code = slmp.read_cputype()
        print("CPU = {0}, Code={1}".format(cpu_type, cpu_code))

        cnt = cnt + 1
        time.sleep(1)


    return 0

if __name__ == '__main__':
    main()
